==> RFA_0.0-4.tar.gz: RFA/data/region.R <==
region <- list(c(10.90,12.50,28.60,22.50,27.80,10.30,12.20,12.50,32.10,25.50,9.45,10.00,12.20,9.45,9.45,9.45,8.91,17.50,10.90,14.50,12.50,9.73,37.90,10.60,8.63,24.40,24.00,9.45,51.80,11.10,10.30,10.80,14.50,9.98,9.44,21.40,9.44,8.35,17.40,9.44,8.90,8.35,10.80,17.10,8.35,9.98,56.60,11.90,8.86,11.90,8.86,30.90,12.20,15.00,10.30,8.58,26.60,13.10,8.58,10.60,43.00,20.40,9.53,10.20,10.00,9.79,49.90),
               c(9.50,10.10,6.05,8.39,14.00,18.80,12.10,6.73,6.50,8.12,8.95,6.73,23.60,13.40,8.12,6.27,11.20,31.90,6.27,20.60,8.39,29.20,24.40,48.60,22.90,7.84,17.30,9.22,6.50,13.70,32.30,12.70,6.82,6.93,6.27,8.31,27.60,15.20,6.56,10.20,7.76,10.90,8.75,8.67,16.90,12.90,10.70,9.69,7.84,9.28,5.96,37.00,11.10,9.36,7.95,12.00,22.90,8.28,6.10,22.00,19.60,26.00,6.93,8.53,9.89,59.50),
               c(13.90,7.75,5.38,13.50,9.48,5.01,6.00,6.38,8.48,4.56,7.18,5.76,6.75,5.01,17.40,4.45,8.33,20.70,7.75,49.00,9.63,4.98,15.20,10.30,4.88,4.55,4.88,21.50,6.93,5.86,6.53,4.77,4.55,6.13,4.88,5.33,10.70,6.26,7.47,6.66,8.80,5.86,4.99,29.80,6.51,4.67,6.51,7.83,6.92,8.98,5.90,4.41,4.57,4.82,7.36,13.00,5.84,4.52,4.89,10.50,14.40,7.39,7.31,9.86,40.20),
               c(24.0000,21.7000,46.7000,29.9000,36.4000,26.9000,37.8000,31.100,39.3000,33.4000,39.3000,22.8000,31.7000,22.2000,24.6000,51.9000,32.3000,31.7000,40.0000,25.7000,22.2000,25.7000,31.1000,28.1000,76.8000,110.0000,23.4000,48.2000,73.3000,22.2000,51.2000,30.5000,32.9000,21.7000,37.1000,112.0000,31.1000,34.0000,26.9000,24.6000,195.0000,45.2000,24.6000,26.0000,23.3000,29.8000,28.1000,39.9000,43.4000,51.2000,24.0000,49.1000,23.0000,40.4000,23.1000,48.6000,45.7000,27.9000,24.7000,25.0000,34.0000),
               c(15.4,14.9,16.7,19.4,11.9,14.7,15.7,11.1,20.7,12.1,22.3,11.9,16.5,11.6,14.2,17.3,10.7,10.9,12.3,35.1,13.5,19.1,17.3,20.5,12.3,11.9,11.1,22.3,48.5,12.3,17.3,18.9,23.9,11.9,24.5,18.1,14.7,11.6,11.7,21.5,20.2,14.5,30.4,20.8,11.0,17.5,15.2,14.8,23.5,10.8,46.9,20.2,28.5,16.5,13.5,11.4,15.5,12.0,12.1,16.1,15.4,14.1,56.1),
               c(7.84,10.90,10.00,9.55,14.30,9.79,12.30,16.90,11.30,10.00,20.40,13.40,33.20,14.30,9.30,9.55,10.50,12.60,7.20,8.81,9.05,7.41,16.30,15.20,32.90,44.60,17.80,9.09,7.58,7.18,22.90,7.18,7.38,10.30,8.58,11.00,8.18,8.18,14.50,8.78,12.60,8.50,15.10,9.18,10.00,10.90,15.50,7.20,7.36,9.50,8.66,7.76,35.80,8.62,7.99,12.00,7.69,7.20,9.45,15.80,18.10,24.20,13.40,10.40,15.30,10.50,58.40),
               c(5.41,4.27,5.74,5.41,9.00,9.61,5.09,5.25,7.98,22.30,8.60,28.50,4.59,4.92,7.78,4.76,12.90,8.39,4.27,8.39,9.82,6.97,5.74,8.19,13.70,14.70,4.43,4.43,6.23,5.58,4.76,6.23,6.07,8.39,5.90,8.80,7.17,9.82,5.58,16.10,6.23,4.27,8.80,7.98,6.23,7.98,14.90,7.58,5.09,7.58,13.50,8.62,5.13,4.30,4.13,6.56,4.91,4.41,8.68,4.68,7.94,5.05,4.56,11.50,14.30),
               c(1.88,1.88,4.00,1.88,2.36,2.75,2.26,2.56,2.56,1.97,1.78,2.85,2.65,3.04,2.36,2.46,2.36,1.88,1.78,2.94,4.35,2.46,3.33,3.33,1.88,2.46,2.46,1.78,1.97,2.46,2.75,1.97,2.65,2.36,2.26,1.78,2.17,1.97,2.07,5.38,2.94,1.97,2.17,2.07,4.00,2.17,2.07,3.89,1.88,2.36,2.36,2.85,2.17,4.00,1.78,1.73,2.56,2.54,3.23,3.65,2.11,3.65,2.06,3.49,5.01),
               c(8.94,10.40,8.52,5.72,6.45,5.54,8.73,10.60,6.09,6.66,6.86,5.90,6.66,6.45,6.09,6.45,5.90,5.54,10.40,7.90,6.09,18.30,8.48,11.00,9.55,8.07,8.07,5.42,5.42,9.33,19.50,8.91,8.28,5.59,7.26,5.93,5.93,5.42,9.33,5.93,7.05,7.05,10.40,13.50,12.00,10.60,6.19,11.30,14.70,9.03,11.50,13.30,5.51,8.02,18.80,15.20,5.81,5.71,5.45,8.28,10.30,8.37,10.30,5.53,7.20,6.70,23.60,44.20,10.00,10.90,7.78,7.89,13.60,13.70),
               c(61.20000,46.70000,32.70000,41.50000,39.70000,40.10000,47.70000,,31.30000,58.60000,35.50000,42.00000,41.50000,47.70000,43.40000,32.20000,32.20000,60.60000,33.60000,29.90000,68.90000,56.00000,35.50000,38.70000,112.00001,52.40000,91.80000,65.80000,83.80000,138.00000,51.30000,60.60000,33.20000,66.30000,55.20000,72.60001,34.10000,89.80000,97.90000,32.80000,38.60000,32.40000,49.60000,41.80000,30.90000,40.30000,30.20000,75.20000,31.60000,80.60001,61.90000,47.10000,49.30000,64.70000,45.60000,110.00001,58.30000,30.70000,35.90000,39.30000,35.90000,53.80000,55.80000,63.00000,62.00000,44.50000,57.80000,70.40000,61.50000,150.00000),
               c(15.80000,17.40000,17.40000,21.30000,26.30000,15.10000,13.90000,14.30000,22.90000,15.40000,38.40000,18.20000,13.90000,15.40000,40.00000,14.70000,22.10000,14.30000,20.60000,20.20000,15.40000,17.00000,33.00000,28.10000,23.70000,20.20000,41.10000,42.60000,37.40000,125.00001,37.00000,15.40000,15.80000,41.10000,14.30000,38.50000,20.60000,21.00000,16.20000,16.00000,71.60001,15.40000,25.00000,27.40000,22.90000,16.50000,53.70000,42.10000,45.70000,36.10000,14.60000,29.50000,14.30000,23.10000,73.00000,19.90000,24.00000,18.40000,18.90000,31.30000,14.50000,16.60000,16.70000,36.00000,19.20000,84.70000,46.90000,14.00000,37.10000,54.30000,15.40000,27.20000,22.50000,76.80000),
               c(66.60001,180.00002,83.20000,105.00001,128.00000,157.00000,158.00000,164.00002,77.00000,215.00002,123.00001,97.10001,117.00001,127.00001,259.00000,146.00000,58.10000,73.50000,59.90000,73.90000,102.00001,77.60001,62.60000,68.40000,57.20000,68.80000,63.10000,189.00002,94.80000,62.60000,94.30000,68.30000,58.90000,74.20000,110.00001,196.00002,58.80000,64.30000,154.00000,69.90000,124.00001,160.00000,108.00001,300.00000,87.10001),
               c(3.07,4.46,3.39,5.76,7.02,4.59,3.50,3.39,3.07,3.28,3.72,4.46,6.71,4.72,3.28,3.07,4.20,4.72,4.98,3.18,4.72,5.37,7.02,9.35,14.30,3.28,7.49,6.02,5.50,4.85,5.76,4.07,23.50,14.10,5.11,4.08,3.57,4.10,3.38,3.14,7.19,4.14,10.40,8.19,4.47,3.70,7.47,3.49,4.80,3.19,11.50,4.64,4.03,5.64,4.11,6.59,5.90,5.90,17.10,7.91,7.75,4.92,3.46,7.12,5.16,7.97,4.42,9.04,5.24,8.89,12.70,3.28,3.84,54.00),
               c(41.20000,39.10000,62.70000,61.20000,41.50000,98.20000,54.50000,53.70000,39.30000,112.00001,46.90000,78.80000,38.50000,46.10000,36.20000,97.30000,45.00000,58.90000,54.00000,33.80000,57.80000,88.70000,101.00001,93.40000,71.80000,58.60000,129.00000,36.40000,57.00000,53.20000,56.30000,37.70000,75.70000,103.00001,33.20000,68.40000,89.60001,60.30000,44.70000,34.50000,45.50000,59.80000,69.00000,135.00000,34.50000,228.00002),
               c(2.89,4.24,2.89,2.59,2.89,2.59,2.89,3.39,2.59,3.72,2.73,7.36,4.05,3.88,4.05,4.24,3.39,4.98,4.24,2.89,2.59,3.88,2.59,3.40,2.59,2.75,3.23,3.88,2.75,3.72,3.28,3.19,4.07,3.27,3.30,7.52,7.16,4.10,10.30,3.04,9.59,3.30,2.57,3.77,4.05,2.94,2.93,5.15,3.72,4.52,3.80,2.60,5.37,8.60,17.30),
               c(32.91246,32.35445,26.98433,29.05543,29.93063,31.45276,30.69912,32.22307,33.39904,32.78479,33.76815,21.06164,34.08090,22.49360,25.71637)
               )
names(region) <- c(paste("Site ",1:15,sep=""),"record")

==> RFA_0.0-7.tar.gz: RFA/data/region.R <==
region <- list(c(10.90,12.50,28.60,22.50,27.80,10.30,12.20,12.50,32.10,25.50,9.45,10.00,12.20,9.45,9.45,9.45,8.91,17.50,10.90,14.50,12.50,9.73,37.90,10.60,8.63,24.40,24.00,9.45,51.80,11.10,10.30,10.80,14.50,9.98,9.44,21.40,9.44,8.35,17.40,9.44,8.90,8.35,10.80,17.10,8.35,9.98,56.60,11.90,8.86,11.90,8.86,30.90,12.20,15.00,10.30,8.58,26.60,13.10,8.58,10.60,43.00,20.40,9.53,10.20,10.00,9.79,49.90),
               c(9.50,10.10,6.05,8.39,14.00,18.80,12.10,6.73,6.50,8.12,8.95,6.73,23.60,13.40,8.12,6.27,11.20,31.90,6.27,20.60,8.39,29.20,24.40,48.60,22.90,7.84,17.30,9.22,6.50,13.70,32.30,12.70,6.82,6.93,6.27,8.31,27.60,15.20,6.56,10.20,7.76,10.90,8.75,8.67,16.90,12.90,10.70,9.69,7.84,9.28,5.96,37.00,11.10,9.36,7.95,12.00,22.90,8.28,6.10,22.00,19.60,26.00,6.93,8.53,9.89,59.50),
               c(13.90,7.75,5.38,13.50,9.48,5.01,6.00,6.38,8.48,4.56,7.18,5.76,6.75,5.01,17.40,4.45,8.33,20.70,7.75,49.00,9.63,4.98,15.20,10.30,4.88,4.55,4.88,21.50,6.93,5.86,6.53,4.77,4.55,6.13,4.88,5.33,10.70,6.26,7.47,6.66,8.80,5.86,4.99,29.80,6.51,4.67,6.51,7.83,6.92,8.98,5.90,4.41,4.57,4.82,7.36,13.00,5.84,4.52,4.89,10.50,14.40,7.39,7.31,9.86,40.20),
               c(24.0000,21.7000,46.7000,29.9000,36.4000,26.9000,37.8000,31.100,39.3000,33.4000,39.3000,22.8000,31.7000,22.2000,24.6000,51.9000,32.3000,31.7000,40.0000,25.7000,22.2000,25.7000,31.1000,28.1000,76.8000,110.0000,23.4000,48.2000,73.3000,22.2000,51.2000,30.5000,32.9000,21.7000,37.1000,112.0000,31.1000,34.0000,26.9000,24.6000,195.0000,45.2000,24.6000,26.0000,23.3000,29.8000,28.1000,39.9000,43.4000,51.2000,24.0000,49.1000,23.0000,40.4000,23.1000,48.6000,45.7000,27.9000,24.7000,25.0000,34.0000),
               c(15.4,14.9,16.7,19.4,11.9,14.7,15.7,11.1,20.7,12.1,22.3,11.9,16.5,11.6,14.2,17.3,10.7,10.9,12.3,35.1,13.5,19.1,17.3,20.5,12.3,11.9,11.1,22.3,48.5,12.3,17.3,18.9,23.9,11.9,24.5,18.1,14.7,11.6,11.7,21.5,20.2,14.5,30.4,20.8,11.0,17.5,15.2,14.8,23.5,10.8,46.9,20.2,28.5,16.5,13.5,11.4,15.5,12.0,12.1,16.1,15.4,14.1,56.1),
               c(7.84,10.90,10.00,9.55,14.30,9.79,12.30,16.90,11.30,10.00,20.40,13.40,33.20,14.30,9.30,9.55,10.50,12.60,7.20,8.81,9.05,7.41,16.30,15.20,32.90,44.60,17.80,9.09,7.58,7.18,22.90,7.18,7.38,10.30,8.58,11.00,8.18,8.18,14.50,8.78,12.60,8.50,15.10,9.18,10.00,10.90,15.50,7.20,7.36,9.50,8.66,7.76,35.80,8.62,7.99,12.00,7.69,7.20,9.45,15.80,18.10,24.20,13.40,10.40,15.30,10.50,58.40),
               c(5.41,4.27,5.74,5.41,9.00,9.61,5.09,5.25,7.98,22.30,8.60,28.50,4.59,4.92,7.78,4.76,12.90,8.39,4.27,8.39,9.82,6.97,5.74,8.19,13.70,14.70,4.43,4.43,6.23,5.58,4.76,6.23,6.07,8.39,5.90,8.80,7.17,9.82,5.58,16.10,6.23,4.27,8.80,7.98,6.23,7.98,14.90,7.58,5.09,7.58,13.50,8.62,5.13,4.30,4.13,6.56,4.91,4.41,8.68,4.68,7.94,5.05,4.56,11.50,14.30),
               c(1.88,1.88,4.00,1.88,2.36,2.75,2.26,2.56,2.56,1.97,1.78,2.85,2.65,3.04,2.36,2.46,2.36,1.88,1.78,2.94,4.35,2.46,3.33,3.33,1.88,2.46,2.46,1.78,1.97,2.46,2.75,1.97,2.65,2.36,2.26,1.78,2.17,1.97,2.07,5.38,2.94,1.97,2.17,2.07,4.00,2.17,2.07,3.89,1.88,2.36,2.36,2.85,2.17,4.00,1.78,1.73,2.56,2.54,3.23,3.65,2.11,3.65,2.06,3.49,5.01),
               c(8.94,10.40,8.52,5.72,6.45,5.54,8.73,10.60,6.09,6.66,6.86,5.90,6.66,6.45,6.09,6.45,5.90,5.54,10.40,7.90,6.09,18.30,8.48,11.00,9.55,8.07,8.07,5.42,5.42,9.33,19.50,8.91,8.28,5.59,7.26,5.93,5.93,5.42,9.33,5.93,7.05,7.05,10.40,13.50,12.00,10.60,6.19,11.30,14.70,9.03,11.50,13.30,5.51,8.02,18.80,15.20,5.81,5.71,5.45,8.28,10.30,8.37,10.30,5.53,7.20,6.70,23.60,44.20,10.00,10.90,7.78,7.89,13.60,13.70),
               c(61.20000,46.70000,32.70000,41.50000,39.70000,40.10000,47.70000,31.30000,58.60000,35.50000,42.00000,41.50000,47.70000,43.40000,32.20000,32.20000,60.60000,33.60000,29.90000,68.90000,56.00000,35.50000,38.70000,112.00001,52.40000,91.80000,65.80000,83.80000,138.00000,51.30000,60.60000,33.20000,66.30000,55.20000,72.60001,34.10000,89.80000,97.90000,32.80000,38.60000,32.40000,49.60000,41.80000,30.90000,40.30000,30.20000,75.20000,31.60000,80.60001,61.90000,47.10000,49.30000,64.70000,45.60000,110.00001,58.30000,30.70000,35.90000,39.30000,35.90000,53.80000,55.80000,63.00000,62.00000,44.50000,57.80000,70.40000,61.50000,150.00000),
               c(15.80000,17.40000,17.40000,21.30000,26.30000,15.10000,13.90000,14.30000,22.90000,15.40000,38.40000,18.20000,13.90000,15.40000,40.00000,14.70000,22.10000,14.30000,20.60000,20.20000,15.40000,17.00000,33.00000,28.10000,23.70000,20.20000,41.10000,42.60000,37.40000,125.00001,37.00000,15.40000,15.80000,41.10000,14.30000,38.50000,20.60000,21.00000,16.20000,16.00000,71.60001,15.40000,25.00000,27.40000,22.90000,16.50000,53.70000,42.10000,45.70000,36.10000,14.60000,29.50000,14.30000,23.10000,73.00000,19.90000,24.00000,18.40000,18.90000,31.30000,14.50000,16.60000,16.70000,36.00000,19.20000,84.70000,46.90000,14.00000,37.10000,54.30000,15.40000,27.20000,22.50000,76.80000),
               c(66.60001,180.00002,83.20000,105.00001,128.00000,157.00000,158.00000,164.00002,77.00000,215.00002,123.00001,97.10001,117.00001,127.00001,259.00000,146.00000,58.10000,73.50000,59.90000,73.90000,102.00001,77.60001,62.60000,68.40000,57.20000,68.80000,63.10000,189.00002,94.80000,62.60000,94.30000,68.30000,58.90000,74.20000,110.00001,196.00002,58.80000,64.30000,154.00000,69.90000,124.00001,160.00000,108.00001,300.00000,87.10001),
               c(3.07,4.46,3.39,5.76,7.02,4.59,3.50,3.39,3.07,3.28,3.72,4.46,6.71,4.72,3.28,3.07,4.20,4.72,4.98,3.18,4.72,5.37,7.02,9.35,14.30,3.28,7.49,6.02,5.50,4.85,5.76,4.07,23.50,14.10,5.11,4.08,3.57,4.10,3.38,3.14,7.19,4.14,10.40,8.19,4.47,3.70,7.47,3.49,4.80,3.19,11.50,4.64,4.03,5.64,4.11,6.59,5.90,5.90,17.10,7.91,7.75,4.92,3.46,7.12,5.16,7.97,4.42,9.04,5.24,8.89,12.70,3.28,3.84,54.00),
               c(41.20000,39.10000,62.70000,61.20000,41.50000,98.20000,54.50000,53.70000,39.30000,112.00001,46.90000,78.80000,38.50000,46.10000,36.20000,97.30000,45.00000,58.90000,54.00000,33.80000,57.80000,88.70000,101.00001,93.40000,71.80000,58.60000,129.00000,36.40000,57.00000,53.20000,56.30000,37.70000,75.70000,103.00001,33.20000,68.40000,89.60001,60.30000,44.70000,34.50000,45.50000,59.80000,69.00000,135.00000,34.50000,228.00002),
               c(2.89,4.24,2.89,2.59,2.89,2.59,2.89,3.39,2.59,3.72,2.73,7.36,4.05,3.88,4.05,4.24,3.39,4.98,4.24,2.89,2.59,3.88,2.59,3.40,2.59,2.75,3.23,3.88,2.75,3.72,3.28,3.19,4.07,3.27,3.30,7.52,7.16,4.10,10.30,3.04,9.59,3.30,2.57,3.77,4.05,2.94,2.93,5.15,3.72,4.52,3.80,2.60,5.37,8.60,17.30),
               c(32.91246,32.35445,26.98433,29.05543,29.93063,31.45276,30.69912,32.22307,33.39904,32.78479,33.76815,21.06164,34.08090,22.49360,25.71637)
               )
names(region) <- c(paste("Site ",1:15,sep=""),"record")
